==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/TopologySelectorLabelRequirementBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TopologySelectorLabelRequirementBuilder extends TopologySelectorLabelRequirementFluentImpl<TopologySelectorLabelRequirementBuilder> implements VisitableBuilder<TopologySelectorLabelRequirement,TopologySelectorLabelRequirementBuilder>{
  public TopologySelectorLabelRequirementBuilder() {
    this(false);
  }
  public TopologySelectorLabelRequirementBuilder(Boolean validationEnabled) {
    this(new TopologySelectorLabelRequirement(), validationEnabled);
  }
  public TopologySelectorLabelRequirementBuilder(TopologySelectorLabelRequirementFluent<?> fluent) {
    this(fluent, false);
  }
  public TopologySelectorLabelRequirementBuilder(TopologySelectorLabelRequirementFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TopologySelectorLabelRequirement(), validationEnabled);
  }
  public TopologySelectorLabelRequirementBuilder(TopologySelectorLabelRequirementFluent<?> fluent,TopologySelectorLabelRequirement instance) {
    this(fluent, instance, false);
  }
  public TopologySelectorLabelRequirementBuilder(TopologySelectorLabelRequirementFluent<?> fluent,TopologySelectorLabelRequirement instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withKey(instance.getKey());
      fluent.withValues(instance.getValues());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public TopologySelectorLabelRequirementBuilder(TopologySelectorLabelRequirement instance) {
    this(instance,false);
  }
  public TopologySelectorLabelRequirementBuilder(TopologySelectorLabelRequirement instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withKey(instance.getKey());
      this.withValues(instance.getValues());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  TopologySelectorLabelRequirementFluent<?> fluent;
  Boolean validationEnabled;
  public TopologySelectorLabelRequirement build() {
    TopologySelectorLabelRequirement buildable = new TopologySelectorLabelRequirement(fluent.getKey(),fluent.getValues());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/TopologySelectorLabelRequirementBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TopologySelectorLabelRequirementBuilder extends TopologySelectorLabelRequirementFluent<TopologySelectorLabelRequirementBuilder> implements VisitableBuilder<TopologySelectorLabelRequirement,TopologySelectorLabelRequirementBuilder>{
  public TopologySelectorLabelRequirementBuilder() {
    this(false);
  }
  public TopologySelectorLabelRequirementBuilder(Boolean validationEnabled) {
    this(new TopologySelectorLabelRequirement(), validationEnabled);
  }
  public TopologySelectorLabelRequirementBuilder(TopologySelectorLabelRequirementFluent<?> fluent) {
    this(fluent, false);
  }
  public TopologySelectorLabelRequirementBuilder(TopologySelectorLabelRequirementFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TopologySelectorLabelRequirement(), validationEnabled);
  }
  public TopologySelectorLabelRequirementBuilder(TopologySelectorLabelRequirementFluent<?> fluent,TopologySelectorLabelRequirement instance) {
    this(fluent, instance, false);
  }
  public TopologySelectorLabelRequirementBuilder(TopologySelectorLabelRequirementFluent<?> fluent,TopologySelectorLabelRequirement instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new TopologySelectorLabelRequirement());

    if (instance != null) {
      fluent.withKey(instance.getKey());
      fluent.withValues(instance.getValues());
      fluent.withKey(instance.getKey());
      fluent.withValues(instance.getValues());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public TopologySelectorLabelRequirementBuilder(TopologySelectorLabelRequirement instance) {
    this(instance,false);
  }
  public TopologySelectorLabelRequirementBuilder(TopologySelectorLabelRequirement instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new TopologySelectorLabelRequirement());

    if (instance != null) {
      this.withKey(instance.getKey());
      this.withValues(instance.getValues());
      this.withKey(instance.getKey());
      this.withValues(instance.getValues());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  TopologySelectorLabelRequirementFluent<?> fluent;
  Boolean validationEnabled;
  public TopologySelectorLabelRequirement build() {
    TopologySelectorLabelRequirement buildable = new TopologySelectorLabelRequirement(fluent.getKey(),fluent.getValues());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
